import 'package:flutter/material.dart';
import 'package:get/get.dart';

import 'package:progamification/src/controllers/leader_board.dart';
import 'package:progamification/src/services/sas_token.service.dart';
import 'package:progamification/src/services/storage.service.dart';

class LeaderBoardTable extends StatefulWidget {
  const LeaderBoardTable({super.key});

  @override
  State<LeaderBoardTable> createState() => _LeaderBoardTableState();
}

class _LeaderBoardTableState extends State<LeaderBoardTable> {
  LeaderBoardController leaderBoardController =
      Get.find<LeaderBoardController>();
  SasTokenService sasTokenService = Get.find<SasTokenService>();
  GamificationStorageService storageService =
      Get.find<GamificationStorageService>();
  String sasToken = "";
  String userId = '';
  @override
  initState() {
    super.initState();
    sasTokenService.getSasToken().then((value) {
      setState(() {
        sasToken = value.toString();
      });
    });
    storageService.getString('userId').then((value) => {
          setState(() {
            userId = value.toString();
          })
        });
  }

  @override
  Widget build(BuildContext context) {
    return ListView.builder(
      itemCount: leaderBoardController.leaderBoardData.isNotEmpty
          ? leaderBoardController.leaderBoardData.length
          : 0,
      itemBuilder: (context, i) {
        return leaderBoardController.leaderBoardData.isNotEmpty
            ? Container(
                margin: const EdgeInsets.only(bottom: 2),
                child: ListTile(
                  selected: userId ==
                      leaderBoardController.leaderBoardData[i].userId
                          .toString(),
                  tileColor: const Color(0xFFd4e2ff),
                  leading: Padding(
                    padding:
                        const EdgeInsets.symmetric(horizontal: 0, vertical: 0),
                    child: Container(
                      width: 50.0,
                      height: 50.0,
                      decoration: const BoxDecoration(
                        shape: BoxShape.circle,
                      ),
                      child: ClipOval(
                        child: Image.network(
                            leaderBoardController
                                    .leaderBoardData[i].profileImageUrl
                                    .toString() +
                                sasToken,
                            fit: BoxFit.cover,
                            errorBuilder: (context, child, loadingProgress) =>
                                SizedBox(
                                    width: 50.0,
                                    height: 50.0,
                                    child: Image.asset(
                                        'assets/icons/profile_placeholder.png',
                                        package: 'progamification'))),
                      ),
                    ),
                  ),
                  title: Row(
                      mainAxisAlignment: MainAxisAlignment.spaceBetween,
                      children: [
                        Expanded(
                            flex: 8,
                            child: Text(
                              leaderBoardController.leaderBoardData[i].userName
                                  .toString(),
                              textAlign: TextAlign.start,
                              style: const TextStyle(
                                fontWeight: FontWeight.w600,
                                fontSize: 14,
                              ),
                            )),
                      ]),
                  trailing: Expanded(
                    flex: 2,
                    child: Wrap(
                      spacing: 15.0,
                      children: [
                        Text(
                          "${leaderBoardController.leaderBoardData[i].score.toString()} points",
                          textAlign: TextAlign.start,
                          style: const TextStyle(
                            fontWeight: FontWeight.w600,
                            fontSize: 13,
                          ),
                        ),
                        Text(
                          leaderBoardController.leaderBoardData[i].rank
                              .toString(),
                          textAlign: TextAlign.start,
                          style: const TextStyle(
                            fontWeight: FontWeight.w600,
                            fontSize: 15,
                          ),
                        )
                      ],
                    ),
                  ),
                ),
              )
            : const SizedBox(
                height: 0,
                width: 0,
              );
      },
    );
  }
}
