import 'package:dio/dio.dart';
import 'package:progamification/src/constants/service_urls.dart';
import 'package:progamification/src/services/storage.service.dart';
import 'package:progamification/src/utilities/http_client.dart';
import 'package:jwt_decoder/jwt_decoder.dart';
import 'package:shared_preferences/shared_preferences.dart';

class GamificationAuthService {
  static Future<bool> init(String clientId, String clientSecret) async {
    var httpClient = getHttpClient();
    Response response = await httpClient.get(
      ServiceUrls.getAuthTokens(clientId, clientSecret),
    );
    if (response.statusCode == 200) {
      var data = response.data;
      var accessToken = data['data']['tokens']['accessToken'];
      var refreshToken = data['data']['tokens']['refreshToken'];
      await GamificationStorageService.setString(
          'gamificationAccessToken', accessToken);
      await GamificationStorageService.setString('refreshToken', refreshToken);
      return true;
    }
    return false;
  }

  static Future<bool> checkAccess() async {
    SharedPreferences preferences = await SharedPreferences.getInstance();
    var accessToken = preferences.getString('gamificationAccessToken');
    var refreshToken = preferences.getString('refreshToken');
    if (accessToken == null || refreshToken == null) {
      return false;
    }
    bool isExpired = JwtDecoder.isExpired(accessToken);
    if (isExpired) {
      return false;
    }
    return true;
  }
}
